# 1.1
- Restore archive_safely, unarchive_safely
- Restore check_relative_path, get_relative_path
- Restore has_extension, is_matching_paths, walk_paths

# 1.0
- Restore TemporaryStorage, make_folder, make_unique_folder
- Restore remove_folder, remove_path
- Restore check_absolute_path, get_absolute_path, get_real_path
- Restore make_enumerated_folder, make_random_folder
